=======
copydoc
=======

.. image:: https://travis-ci.org/nprapps/copydoc.png
    :target: https://travis-ci.org/nprapps/copydoc
    :alt: Build status

.. image:: https://img.shields.io/pypi/dw/copydoc.svg
    :target: https://pypi.python.org/pypi/copydoc
    :alt: PyPI downloads

.. image:: https://img.shields.io/pypi/v/copydoc.svg
    :target: https://pypi.python.org/pypi/copydoc
    :alt: Version

.. image:: https://img.shields.io/pypi/l/copydoc.svg
    :target: https://github.com/nprapps/copydoc/blob/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/copydoc.svg
    :target: https://pypi.python.org/pypi/copydoc
    :alt: Support Python versions

Like copytext, but for docs
